pub struct CreateBucketReqeust {
pub bucket_name: String,
}Expand description
Request payload for creating a bucket.
Fields
bucket_name: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for CreateBucketReqeust
impl<'de> Deserialize<'de> for CreateBucketReqeust
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateBucketReqeust
impl JsonSchema for CreateBucketReqeust
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateBucketReqeust
impl RefUnwindSafe for CreateBucketReqeust
impl Send for CreateBucketReqeust
impl Sync for CreateBucketReqeust
impl Unpin for CreateBucketReqeust
impl UnsafeUnpin for CreateBucketReqeust
impl UnwindSafe for CreateBucketReqeust